pub struct RenderExtractedVisibleEntities {
pub classes: IndexMap<TypeId, RenderExtractedVisibleEntitiesClass, NoOpHash>,
}Expand description
The entities that the CPU has determined are visible from a single view or subview.
This component is only placed directly on camera entities. Lights instead
have a RenderExtractedShadowMapVisibleEntities component that contains
one or more RenderExtractedVisibleEntities components, one for each
cascade or cubemap side.
Mesh entities with NoCpuCulling aren’t present in this table. Instead,
collect_gpu_culled_meshes fetches them directly from the
RenderGpuCulledEntities list.
The crate::camera::extract_cameras and extract_lights systems populate
this object, and the collect_visible_cpu_culled_entities system reads it.
Fields
classes: IndexMap<TypeId, RenderExtractedVisibleEntitiesClass, NoOpHash>Entities that the CPU has determined to be visible from this view or
subview, sorted by VisibilityClass.