RenderVisibleEntitiesClass

Struct RenderVisibleEntitiesClass 

pub struct RenderVisibleEntitiesClass {
    pub entities_cpu_culling: Vec<(Entity, MainEntity)>,
    pub entities_gpu_culling: HashMap<MainEntity, Entity, EntityHash>,
    pub added_entities: Vec<(Entity, MainEntity)>,
    pub removed_entities: Vec<(Entity, MainEntity)>,
}
Stores a list of all entities that are visible from a single view for a single VisibilityClass, as well as the change lists.

Note that all lists in this component are guaranteed to be sorted. Thus you can test for the presence of an entity in these lists via binary search.

Note also that, for 3D meshes, the render-world Entity values will always be Entity::PLACEHOLDER. The render-world entities are kept for legacy systems that still need to process visibility of render-world entities.

The collect_visible_cpu_culled_entities and collect_gpu_culled_meshes systems populate this object from the corresponding RenderExtractedVisibleEntitiesClass object and the RenderGpuCulledEntities resource, respectively.

Fields

entities_cpu_culling: Vec<(Entity, MainEntity)>

A sorted list of all entities that don’t have NoCpuCulling components and are visible from this view.

entities_gpu_culling: HashMap<MainEntity, Entity, EntityHash>

A table of all entities that have NoCpuCulling components and have bevy_camera::visibility::InheritedVisibility set to true.

The collect_gpu_culled_meshes system keeps this up to date.

added_entities: Vec<(Entity, MainEntity)>

A sorted list of all entities that were invisible last frame (including ones that didn’t exist at all last frame) and became visible this frame.

removed_entities: Vec<(Entity, MainEntity)>

A sorted list of all entities that were visible last frame and became invisible this frame, including those that were despawned this frame.

Implementations

Source

impl RenderVisibleEntitiesClass

pub fn prepare_for_new_frame(&mut self)

Clears out the lists of added and removed entities in preparation for a new frame.

pub fn update_cpu_culled_entities( &mut self, visible_mesh_entities_cpu_culling: &[(Entity, MainEntity)], )

Processes a list of visible entities for a new frame, computing the set of newly-added and newly-removed entities as it goes.

This function only handles entities that are culled on CPU (i.e. don’t have NoCpuCulling components). Entities that use only GPU culling are instead fetched from the main world and added to the RenderGpuCulledEntities table.

pub fn add_entity(&mut self, pair: (Entity, MainEntity))

Adds a new entity to the Self::added_entities list.

After calling this method one or more times, you must call Self::sort_added_entities to ensure the Self::added_entities list is sorted.

pub fn added_entities(&self) -> &[(Entity, MainEntity)]

Returns the list of newly-added entities.

pub fn entity_pair_is_visible( &self, entity: Entity, main_entity: MainEntity, ) -> bool

Returns true if the given entity pair is known to be visible.

This checks both the CPU culling visible entries table and the no-CPU-culling visible entries table.

pub fn iter_visible<'a>( &'a self, ) -> impl Iterator<Item = (&'a Entity, &'a MainEntity)>

Iterates over all visible entities.

This is an expensive operation, so try to avoid doing it unless necessary (e.g. the view key changed).

pub fn sort_added_entities(&mut self)

Sorts the Self::added_entities list.

You must call this after adding entities to the list via Self::add_entity.